#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for GNU Typist -- well known typing tutor.
#---( Source URL: http://www.gnu.org/software/gtypist/
#---( Build script by R S Ananda Murthy (rsamurti@airtelbroadband.in)
#---( Date build script was last modified: Monday, 21-Jan-2008.


#------------------( Set Package Name & Version )


soft='gtypist'
softversion='2.7'
packageversion='52.1'


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS )


chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu" 


#------------------( Configure, Make And Install The Software )


cd $src

./configure --prefix=/usr \
--bindir=/usr/bin \
--mandir=/usr/man 

make DESTDIR=$dest
make install DESTDIR=$dest


#------------------( Strip Executables (Comment out these lines if debugging info is needed) )


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)


#------------------( Compress Man Pages and Info Pages and Move To Correct Location )


( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

( cd $dest/usr/info
  find . -name "*.info" | xargs gzip -9
  rm -f dir
)


#------------------( Move Documentation To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS COPYING NEWS README INSTALL \
  $dest/usr/doc/$soft-$softversion
cp $src/doc/*.htm* $dest/usr/doc/$soft-$softversion

rm -rf $dest/usr/share/doc


#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( We Made A Custom Icon, Let's Copy It For Next Time )


cp $buildir/gtypist.png $dest/usr/src/$soft-$softversion/gtypist.png
chmod -x $dest/usr/src/$soft-$softversion/gtypist.png


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
       |-----handy-ruler------------------------------------------------------|
gtypist: gtypist (A free universal typing tutor)
gtypist:
gtypist: GNU Typist (also called gtypist) is a universal typing tutor. You
gtypist: can learn correct typing and improve your skills by practicing it's 
gtypist: exercises on a regular basis.
gtypist: 
gtypist: 
gtypist:
gtypist: 
gtypist:
gtypist: 
EOF

#------------------( Create The Doinst.sh File)


cat <<EOF > $dest/install/doinst.sh
##Install info files for the package.
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=/usr/info /usr/info/gtypist.info.gz 2>/dev/null
fi
EOF


#------------------( Create The Desktop Menu Entry )


mkdir -p $dest/usr/share/applications
cat <<EOF > $dest/usr/share/applications/$soft.desktop
[Desktop Entry]
Encoding=UTF-8
Name=GNU Typist
Comment=Free Typing Tutor
Exec=gtypist
Terminal=true
Type=Application
Categories=Application;Office;
Icon=gtypist
StartupNotify=true
EOF

#------------------( Copy The Icon To The Correct Location )


mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
cp $buildir/gtypist.png $dest/usr/share/icons/hicolor/48x48/apps/gtypist.png
chmod -x $dest/usr/share/icons/hicolor/48x48/apps/gtypist.png


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum and Check Package )


cd $buildir
zen-pkgcheck.pl $package.tgz
md5sum $package.tgz > $package.md5
requiredbuilder -z $package.tgz > $package.dep